==> claromentis-framework-8.13.65-b8aa1bfb.zip: web/intranet/infocapture/classes/ExpressionLanguage/ParseError.php <==
<?php
namespace Claromentis\Infocapture\ExpressionLanguage;

$GLOBALS["__65da1b1ec2d6653e8a0ab78" . "48e536215"] = (@$GLOBALS["__65da1b1ec2d6653e8a0ab7" . "848e536215"] ?: array()) + array();
use Throwable;
class ParseError extends \Exception
{
    protected $parsed_line = 0;
    
    
    
    
    protected $unexpected_token;
    
    
    
    
    protected $expected_tokens;
    
    
    
    
    private $parsed_offset = 0;
    public function __construct($message = "", $_a2da5768d1ad9473e979acaaeb98624c = 0, $_1f50e30be8c2fefa6881834e71d504a2 = 0, $_14754d2eafa9e644bfb1b85c14b16e73 = "", $_7347863a71ac3a20961955bfb097b900 = [])
    {
        parent::__construct($message);
        $this->parsed_line = $_a2da5768d1ad9473e979acaaeb98624c;
        $this->parsed_offset = $_1f50e30be8c2fefa6881834e71d504a2;
        $this->unexpected_token = $_14754d2eafa9e644bfb1b85c14b16e73;
        $this->expected_tokens = $_7347863a71ac3a20961955bfb097b900;
    }
    public function GetRawLine()
    {
        return $this->parsed_line;
    }
    public function SetRawLine($_a2da5768d1ad9473e979acaaeb98624c)
    {
        $this->parsed_line = $_a2da5768d1ad9473e979acaaeb98624c;
    }
    public function GetColumn()
    {
        return $this->parsed_offset;
    }
    public function SetColumn(int $_39ee6ebc906f3b410a43566f3d34d868)
    {
        $this->parsed_offset = $_39ee6ebc906f3b410a43566f3d34d868;
    }
    
    
    
    
    public function GetUnexpectedToken() : string
    {
        return $this->unexpected_token;
    }
    
    
    
    
    public function SetUnexpectedToken(string $_14754d2eafa9e644bfb1b85c14b16e73) : void
    {
        $this->unexpected_token = $_14754d2eafa9e644bfb1b85c14b16e73;
    }
    
    
    
    
    public function GetExpectedTokens() : array
    {
        return $this->expected_tokens;
    }
    
    
    
    
    public function SetExpectedTokens(array $_7347863a71ac3a20961955bfb097b900) : void
    {
        $this->expected_tokens = $_7347863a71ac3a20961955bfb097b900;
    }
}

==> claromentis-framework-9.6.5-177028fb.zip: web/intranet/infocapture/classes/ExpressionLanguage/ParseError.php <==
<?php
namespace Claromentis\Infocapture\ExpressionLanguage;

$GLOBALS["__65da1b1ec2d" . "6653e8a0ab784" . "8e536215"] = (@$GLOBALS["__65da1b1ec2d6653e8a0ab78" . "48e536215"] ?: array()) + array();
use Throwable;
class ParseError extends \Exception
{
    protected $parsed_line = 0;
    
    
    
    
    protected $unexpected_token;
    
    
    
    
    protected $expected_tokens;
    
    
    
    
    private $parsed_offset = 0;
    public function __construct($message = "", $_a2da5768d1ad9473e979acaaeb98624c = 0, $_1f50e30be8c2fefa6881834e71d504a2 = 0, $_14754d2eafa9e644bfb1b85c14b16e73 = "", $_7347863a71ac3a20961955bfb097b900 = [])
    {
        parent::__construct($message);
        $this->parsed_line = $_a2da5768d1ad9473e979acaaeb98624c;
        $this->parsed_offset = $_1f50e30be8c2fefa6881834e71d504a2;
        $this->unexpected_token = $_14754d2eafa9e644bfb1b85c14b16e73;
        $this->expected_tokens = $_7347863a71ac3a20961955bfb097b900;
    }
    public function GetRawLine()
    {
        return $this->parsed_line;
    }
    public function SetRawLine($_a2da5768d1ad9473e979acaaeb98624c)
    {
        $this->parsed_line = $_a2da5768d1ad9473e979acaaeb98624c;
    }
    public function GetColumn()
    {
        return $this->parsed_offset;
    }
    public function SetColumn(int $_39ee6ebc906f3b410a43566f3d34d868)
    {
        $this->parsed_offset = $_39ee6ebc906f3b410a43566f3d34d868;
    }
    
    
    
    
    public function GetUnexpectedToken() : string
    {
        return $this->unexpected_token;
    }
    
    
    
    
    public function SetUnexpectedToken(string $_14754d2eafa9e644bfb1b85c14b16e73) : void
    {
        $this->unexpected_token = $_14754d2eafa9e644bfb1b85c14b16e73;
    }
    
    
    
    
    public function GetExpectedTokens() : array
    {
        return $this->expected_tokens;
    }
    
    
    
    
    public function SetExpectedTokens(array $_7347863a71ac3a20961955bfb097b900) : void
    {
        $this->expected_tokens = $_7347863a71ac3a20961955bfb097b900;
    }
}
